Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(524)

Unified Diff: content/browser/ssl/ssl_manager_unittest.cc

Issue 2444383007: Trigger Dangerous indicator for unsafe subresources (Closed)
Patch Set: protip: #include the .h, not the .cc Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/ssl/ssl_manager_unittest.cc
diff --git a/content/browser/ssl/ssl_manager_unittest.cc b/content/browser/ssl/ssl_manager_unittest.cc
index 8468bb14d12588aa99cbfdc357080608265f9252..7beadeb2c4bd0ae11bf6dd48cd16adc526e9c3be 100644
--- a/content/browser/ssl/ssl_manager_unittest.cc
+++ b/content/browser/ssl/ssl_manager_unittest.cc
@@ -28,7 +28,7 @@ class TestWebContentsDelegate : public WebContentsDelegate {
const SSLStatus& last_ssl_state() { return last_ssl_state_; }
// WebContentsDelegate:
- void VisibleSSLStateChanged(WebContents* source) override {
+ void VisibleSecurityStateChanged(WebContents* source) override {
NavigationEntry* entry = source->GetController().GetVisibleEntry();
EXPECT_TRUE(entry);
last_ssl_state_ = entry->GetSSL();
@@ -48,7 +48,7 @@ class SSLManagerTest : public RenderViewHostTestHarness {
DISALLOW_COPY_AND_ASSIGN(SSLManagerTest);
};
// Tests that VisibleSSLStateChanged() is called when a password input
// is shown on an HTTP page.
TEST_F(SSLManagerTest, NotifyVisibleSSLStateChangeOnHttpPassword) {
TestWebContentsDelegate delegate;
@@ -64,7 +64,7 @@ TEST_F(SSLManagerTest, NotifyVisibleSSLStateChangeOnHttpPassword) {
SSLStatus::DISPLAYED_PASSWORD_FIELD_ON_HTTP);
}
// Tests that VisibleSSLStateChanged() is called when a credit card input
// is shown on an HTTP page.
TEST_F(SSLManagerTest, NotifyVisibleSSLStateChangeOnHttpCreditCard) {
TestWebContentsDelegate delegate;
@@ -80,7 +80,7 @@ TEST_F(SSLManagerTest, NotifyVisibleSSLStateChangeOnHttpCreditCard) {
SSLStatus::DISPLAYED_CREDIT_CARD_FIELD_ON_HTTP);
}
// Tests that VisibleSSLStateChanged() is called when password and
// credit card inputs are shown on an HTTP page.
TEST_F(SSLManagerTest, NotifyVisibleSSLStateChangeOnPasswordAndHttpCreditCard) {
TestWebContentsDelegate delegate;
@@ -48,7 +48,7 @@ class SSLManagerTest : public RenderViewHostTestHarness {
DISALLOW_COPY_AND_ASSIGN(SSLManagerTest);
};
-// Tests that VisibleSSLStateChanged() is called when a password input
+// Tests that VisibleSecurityStateChanged() is called when a password input
// is shown on an HTTP page.
TEST_F(SSLManagerTest, NotifyVisibleSSLStateChangeOnHttpPassword) {
@@ -64,7 +64,7 @@ TEST_F(SSLManagerTest, NotifyVisibleSSLStateChangeOnHttpPassword) {
SSLStatus::DISPLAYED_PASSWORD_FIELD_ON_HTTP);
}
-// Tests that VisibleSSLStateChanged() is called when a credit card input
+// Tests that VisibleSecurityStateChanged() is called when a credit card input
// is shown on an HTTP page.
TEST_F(SSLManagerTest, NotifyVisibleSSLStateChangeOnHttpCreditCard) {
@@ -80,7 +80,7 @@ TEST_F(SSLManagerTest, NotifyVisibleSSLStateChangeOnHttpCreditCard) {
SSLStatus::DISPLAYED_CREDIT_CARD_FIELD_ON_HTTP);
}
-// Tests that VisibleSSLStateChanged() is called when password and
+// Tests that VisibleSecurityStateChanged() is called when password and
// credit card inputs are shown on an HTTP page.
TEST_F(SSLManagerTest, NotifyVisibleSSLStateChangeOnPasswordAndHttpCreditCard) {

Powered by Google App Engine
This is Rietveld 408576698